@@ -2,7 +2,7 @@
 AIfund 是基于 Python 的基金量化工具
 """
 
-__version__ = "0.0.5"
+__version__ = "0.0.6"
 __author__ = "yebaige"
 
 import sys
@@ -13,4 +13,4 @@ if sys.version_info < (3, 7):
 
 del sys
 
-from fund.fund_em import *
+from fund_em import *
